==> instagram_sync-1.0.0.tar.gz: instagram_sync/src/Services/InstagramSyncEntityManager.php <==
<?php

namespace Drupal\instagram_sync\Services;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\file\FileRepositoryInterface;
use Drupal\instagram_sync\Utility\InstagramAPIMedia;
use Drupal\instagram_sync\Utility\InstagramAPIMediaInterface;
use Drupal\instagram_sync\Utility\InstagramApiRemoteResource;
use Drupal\token\TokenInterface;
use Drupal\instagram_sync\Entity\InstagramSync;

/**
 * Service description.
 */
class InstagramSyncEntityManager {

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   *   Entity type manager service variable.
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * Token interface service.
   *
   * @var \Drupal\token\TokenInterface
   *   Token interface service variables.
   */
  protected TokenInterface $tokenManager;

  /**
   * File repository service.
   *
   * @var \Drupal\file\FileRepositoryInterface
   *   File repository service variables.
   */
  protected FileRepositoryInterface $fileRepository;

  /**
   * File system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   *   File system service variable.
   */
  protected FileSystemInterface $fileSystem;

  /**
   * Constructs a new CustomService object.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, TokenInterface $tokenManager, FileRepositoryInterface $fileRepository, FileSystemInterface $fileSystem) {
    $this->entityTypeManager = $entityTypeManager;
    $this->tokenManager = $tokenManager;
    $this->fileRepository = $fileRepository;
    $this->fileSystem = $fileSystem;
  }

  /**
   * Transforms instagram API object to a Drupal entity.
   *
   * @param \Drupal\instagram_sync\Utility\InstagramAPIMediaInterface $instagramAPIMedia
   *   Instagram API media object.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function createInstagramEntity(InstagramAPIMediaInterface $instagramAPIMedia) {
    $storage = $this->entityTypeManager->getStorage('instagram_sync');

    $ids = $storage->getQuery()
      ->condition('label', $instagramAPIMedia->getId())
      ->range(0, 1)
      ->execute();

    // Load the entity if it exists.
    if (empty($ids)) {
      /** @var \Drupal\instagram_sync\Entity\InstagramSync $entity */
      $entity = $storage->create([
        'label' => $instagramAPIMedia->getId(),
        'type' => $instagramAPIMedia->getMediaType(),
      ]);

      $this->saveFiles('instagram_sync_image', $entity, $instagramAPIMedia->getImageUrl());
      $type = $instagramAPIMedia->getMediaType();
      if ($type === InstagramAPIMedia::TYPE_VIDEO) {
        $this->saveFiles('instagram_sync_video_file', $entity, $instagramAPIMedia->getMediaUrl());
      }
    }
    else {
      $id = array_shift($ids);
      $entity = $storage->load($id);
    }
    try {
      $entity->set('caption', $instagramAPIMedia->getCaption());
      $entity->set('like_count', $instagramAPIMedia->getLikeCount());
      $entity->set('comments_count', $instagramAPIMedia->getCommentsCount());
      $entity->set('created', $instagramAPIMedia->getCreatedTime());
      $entity->save();
    }
    catch (\Exception $e) {
      watchdog_exception('error', $e);
    }
  }

  /**
   * Saves media file by URL as a Drupal file.
   *
   * @param string $fieldName
   *   Field to save.
   * @param \Drupal\instagram_sync\Entity\InstagramSync $entity
   *   instagram Entity to process.
   * @param array $resources
   *   Media URLs to save.
   *
   * @return void
   *   Nothing to return.
   */
  protected function saveFiles(string $fieldName, InstagramSync &$entity, array $resources = []) {
    $settings = $entity->getFieldDefinition($fieldName)->getSettings();
    if (!empty($settings)) {
      $scheme = $settings['uri_scheme'] ?? 'public';
      $directory = "{$scheme}://{$settings['file_directory']}/";
      $directory = $this->tokenManager->replace($directory);

      try {
        $this->fileSystem->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY);
        $files = [];
        foreach ($resources as $resource) {
          if ($resource instanceof InstagramApiRemoteResource) {
            $fileName = "{$directory}" . basename($entity->label() . '.' . $resource->getExtension());

            $image_data = file_get_contents($resource->getUrl());
            $file = $this->fileRepository->writeData($image_data, $fileName, FileSystemInterface::EXISTS_RENAME);
            $file->save();
            $files[] = ['target_id' => $file->id()];
          }
        }
        $entity->set($fieldName, $files);
      }
      catch (\Exception $e) {
        watchdog_exception('error', $e);
      }
    }
  }

}

==> instagram_sync-1.1.1.tar.gz: instagram_sync/src/Services/InstagramSyncEntityManager.php <==
<?php

namespace Drupal\instagram_sync\Services;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\file\FileRepositoryInterface;
use Drupal\instagram_sync\Utility\InstagramAPIMedia;
use Drupal\instagram_sync\Utility\InstagramAPIMediaInterface;
use Drupal\instagram_sync\Utility\InstagramApiRemoteResource;
use Drupal\token\TokenInterface;
use Drupal\instagram_sync\Entity\InstagramSync;

/**
 * Service description.
 */
class InstagramSyncEntityManager {

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   *   Entity type manager service variable.
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * Token interface service.
   *
   * @var \Drupal\token\TokenInterface
   *   Token interface service variables.
   */
  protected TokenInterface $tokenManager;

  /**
   * File repository service.
   *
   * @var \Drupal\file\FileRepositoryInterface
   *   File repository service variables.
   */
  protected FileRepositoryInterface $fileRepository;

  /**
   * File system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   *   File system service variable.
   */
  protected FileSystemInterface $fileSystem;

  /**
   * Constructs a new CustomService object.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, TokenInterface $tokenManager, FileRepositoryInterface $fileRepository, FileSystemInterface $fileSystem) {
    $this->entityTypeManager = $entityTypeManager;
    $this->tokenManager = $tokenManager;
    $this->fileRepository = $fileRepository;
    $this->fileSystem = $fileSystem;
  }

  /**
   * Transforms instagram API object to a Drupal entity.
   *
   * @param \Drupal\instagram_sync\Utility\InstagramAPIMediaInterface $instagramAPIMedia
   *   Instagram API media object.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function createInstagramEntity(InstagramAPIMediaInterface $instagramAPIMedia) {
    $storage = $this->entityTypeManager->getStorage('instagram_sync');

    $ids = $storage->getQuery()
      ->condition('label', $instagramAPIMedia->getId())
      ->range(0, 1)
      ->execute();

    // Load the entity if it exists.
    if (empty($ids)) {
      /** @var \Drupal\instagram_sync\Entity\InstagramSync $entity */
      $entity = $storage->create([
        'label' => $instagramAPIMedia->getId(),
        'type' => $instagramAPIMedia->getMediaType(),
      ]);
    }
    else {
      $id = array_shift($ids);
      $entity = $storage->load($id);
    }
    try {
      $entity->set('caption', $instagramAPIMedia->getCaption());
      $entity->set('like_count', $instagramAPIMedia->getLikeCount());
      $entity->set('comments_count', $instagramAPIMedia->getCommentsCount());
      $entity->set('created', $instagramAPIMedia->getCreatedTime());
      $this->saveFiles('instagram_sync_image', $entity, $instagramAPIMedia->getImageUrl());
      if ($instagramAPIMedia->getMediaType() === InstagramAPIMedia::TYPE_VIDEO) {
        $this->saveFiles('instagram_sync_video_file', $entity, $instagramAPIMedia->getMediaUrl());
      }
      $entity->save();
    } catch (\Exception $e) {
      watchdog_exception('error', $e);
    }
  }

  /**
   * Saves media file by URL as a Drupal file.
   *
   * @param string $fieldName
   *   Field to save.
   * @param \Drupal\instagram_sync\Entity\InstagramSync $entity
   *   instagram Entity to process.
   * @param array $resources
   *   Media URLs to save.
   *
   * @return void
   *   Nothing to return.
   */
  protected function saveFiles(string $fieldName, InstagramSync &$entity, array $resources = []) {
    $settings = $entity->getFieldDefinition($fieldName)->getSettings();
    if (!empty($settings)) {
      $scheme = $settings['uri_scheme'] ?? 'public';
      $directory = "{$scheme}://{$settings['file_directory']}/";
      $directory = $this->tokenManager->replace($directory);

      try {
        $this->fileSystem->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY);
        $files = [];
        foreach ($resources as $resource) {
          if ($resource instanceof InstagramApiRemoteResource) {
            $fileName = "{$directory}" . basename($entity->label() . '.' . $resource->getExtension());

            $image_data = file_get_contents($resource->getUrl());
            $file = $this->fileRepository->writeData($image_data, $fileName);
            $file->save();
            $files[] = ['target_id' => $file->id()];
          }
        }
        $entity->set($fieldName, $files);
      } catch (\Exception $e) {
        watchdog_exception('error', $e);
      }
    }
  }

}
